==> runawfe-free-server-4.3.0.tar.gz: runawfe-free-server-4.3.0/wfe-service/src/main/java/ru/runa/wfe/service/client/DelegateProcessVariableProvider.java <==
package ru.runa.wfe.service.client;

import ru.runa.wfe.execution.dto.WfProcess;
import ru.runa.wfe.lang.ProcessDefinition;
import ru.runa.wfe.service.DefinitionService;
import ru.runa.wfe.service.ExecutionService;
import ru.runa.wfe.service.delegate.Delegates;
import ru.runa.wfe.user.IExecutorLoader;
import ru.runa.wfe.user.User;
import ru.runa.wfe.var.AbstractVariableProvider;
import ru.runa.wfe.var.UserType;
import ru.runa.wfe.var.dto.WfVariable;

import com.google.common.base.Objects;

/**
 * Implementation which uses service call for each variable retrieval (through RunaWFE delegates).
 *
 * @author Dofs
 * @since 4.0
 */
public class DelegateProcessVariableProvider extends AbstractVariableProvider {
    protected final ExecutionService executionService;
    protected final DefinitionService definitionService;
    protected final User user;
    protected final Long processId;
    protected Long processDefinitionId;
    protected String processDefinitionName;
    protected ProcessDefinition processDefinition;

    public DelegateProcessVariableProvider(ExecutionService executionService, DefinitionService definitionService, User user, Long processId) {
        this.executionService = executionService;
        this.definitionService = definitionService;
        this.user = user;
        this.processId = processId;
    }

    public DelegateProcessVariableProvider(User user, Long processId) {
        this(Delegates.getExecutionService(), Delegates.getDefinitionService(), user, processId);
    }

    @Override
    protected IExecutorLoader getExecutorLoader() {
        return new DelegateExecutorLoader(user);
    }

    @Override
    public Long getProcessDefinitionId() {
        if (processDefinitionId == null) {
            WfProcess process = executionService.getProcess(user, processId);
            processDefinitionId = process.getDefinitionId();
        }
        return processDefinitionId;
    }

    @Override
    public String getProcessDefinitionName() {
        if (processDefinitionName == null) {
            processDefinitionName = executionService.getProcess(user, processId).getName();
        }
        return processDefinitionName;
    }

    @Override
    public ProcessDefinition getProcessDefinition() {
        if (processDefinition == null) {
            processDefinition = definitionService.getParsedProcessDefinition(user, getProcessDefinitionId());
        }
        return processDefinition;
    }

    @Override
    public Long getProcessId() {
        return processId;
    }

    @Override
    public UserType getUserType(String name) {
        return definitionService.getUserType(user, getProcessDefinitionId(), name);
    }

    @Override
    public Object getValue(String variableName) {
        WfVariable variable = getVariable(variableName);
        if (variable != null) {
            return variable.getValue();
        }
        return null;
    }

    @Override
    public WfVariable getVariable(String variableName) {
        return executionService.getVariable(user, processId, variableName);
    }

    @Override
    public DelegateProcessVariableProvider getSameProvider(Long processId) {
        return new DelegateProcessVariableProvider(executionService, definitionService, user, processId);
    }

    @Override
    public String toString() {
        return Objects.toStringHelper(this).add("processId", processId).toString();
    }

}

==> runawfe-free-server-4.5.0.tar.gz: runawfe-free-server-4.5.0/wfe-service/src/main/java/ru/runa/wfe/service/client/DelegateProcessVariableProvider.java <==
package ru.runa.wfe.service.client;

import com.google.common.base.MoreObjects;
import ru.runa.wfe.execution.dto.WfProcess;
import ru.runa.wfe.lang.ProcessDefinition;
import ru.runa.wfe.service.DefinitionService;
import ru.runa.wfe.service.ExecutionService;
import ru.runa.wfe.service.delegate.Delegates;
import ru.runa.wfe.user.ExecutorLoader;
import ru.runa.wfe.user.User;
import ru.runa.wfe.var.AbstractVariableProvider;
import ru.runa.wfe.var.UserType;
import ru.runa.wfe.var.dto.WfVariable;

/**
 * Implementation which uses service call for each variable retrieval (through RunaWFE delegates).
 *
 * @author Dofs
 * @since 4.0
 */
public class DelegateProcessVariableProvider extends AbstractVariableProvider {
    protected final ExecutionService executionService;
    protected final DefinitionService definitionService;
    protected final User user;
    protected final Long processId;
    protected Long processDefinitionId;
    protected String processDefinitionName;
    protected ProcessDefinition processDefinition;

    public DelegateProcessVariableProvider(ExecutionService executionService, DefinitionService definitionService, User user, Long processId) {
        this.executionService = executionService;
        this.definitionService = definitionService;
        this.user = user;
        this.processId = processId;
    }

    public DelegateProcessVariableProvider(User user, Long processId) {
        this(Delegates.getExecutionService(), Delegates.getDefinitionService(), user, processId);
    }

    @Override
    public ExecutorLoader getExecutorLoader() {
        return new DelegateExecutorLoader(user);
    }

    @Override
    public Long getProcessDefinitionId() {
        if (processDefinitionId == null) {
            WfProcess process = executionService.getProcess(user, processId);
            processDefinitionId = process.getDefinitionId();
        }
        return processDefinitionId;
    }

    @Override
    public String getProcessDefinitionName() {
        if (processDefinitionName == null) {
            processDefinitionName = executionService.getProcess(user, processId).getName();
        }
        return processDefinitionName;
    }

    @Override
    public ProcessDefinition getProcessDefinition() {
        if (processDefinition == null) {
            processDefinition = definitionService.getParsedProcessDefinition(user, getProcessDefinitionId());
        }
        return processDefinition;
    }

    @Override
    public Long getProcessId() {
        return processId;
    }

    @Override
    public UserType getUserType(String name) {
        return definitionService.getUserType(user, getProcessDefinitionId(), name);
    }

    @Override
    public Object getValue(String variableName) {
        WfVariable variable = getVariable(variableName);
        if (variable != null) {
            return variable.getValue();
        }
        return null;
    }

    @Override
    public WfVariable getVariable(String variableName) {
        return executionService.getVariable(user, processId, variableName);
    }

    @Override
    public DelegateProcessVariableProvider getSameProvider(Long processId) {
        return new DelegateProcessVariableProvider(executionService, definitionService, user, processId);
    }

    @Override
    public String toString() {
        return MoreObjects.toStringHelper(this).add("processId", processId).toString();
    }

}
